@@ -3,54 +3,19 @@ package SQL::Catalog;
 use DBI;
 use SQL::Statement;
 use Data::Dumper;
-use Carp;
 
 require 5.005_62;
 use strict;
 use warnings;
 
-our $cache;
-our $VERSION = sprintf '%s', q{$Revision: 1.11 $} =~ /\S+\s+(\S+)/ ;
+our $VERSION = sprintf '%s', q{$Revision: 1.2 $} =~ /\S+\s+(\S+)/ ;
 
+# author , optional
+# denormalize on label
 
 # Preloaded methods go here.
-
-sub cache_enabled {
-    $ENV{SQL_CATALOG_STO} and $ENV{SQL_CATALOG_OPT} ;
-}
-
-
-sub import {
-
-    use Cache::Cache;
-    return unless cache_enabled;
-
-    my $cache_opts = eval " { $ENV{SQL_CATALOG_OPT} } " ;
-    warn "cache_opts ", Dumper($cache_opts);
-    eval "require $ENV{SQL_CATALOG_STO}";
-    $cache = $ENV{SQL_CATALOG_STO}->new ( $cache_opts ) ;
-    confess "Couldnt make $ENV{SQL_CATALOG_STO}" unless $cache;
-
-}
-
-sub cache {
-
-    return unless cache_enabled;
-
-    my ($label, $sql) = @_;
-
-    if ($sql) {
-	warn "$cache->set($label, $sql)";
-	$cache->set($label, $sql);
-    } else {
-	$cache->get($label);
-    }
-
-}
-
 sub load_sql_from {
     my $file = shift;
-    -e $file or croak "File $file does not exist";
     open A, $file or die "cannot open $file";
     join '', <A>;
 }
@@ -79,21 +44,8 @@ sub parse_sql {
      SQL::Statement->new($sql, $parser);
    };
    if ($@) {
-       warn
+       die 
 	   "Cannot parse statement (statement cannot end with semicolon): $@";
-       warn 
-	   "Continuing without SQL validation (good luck).";
-       my $u='unparseable';
-       return { 
-	   command => $u,
-	   params =>  -1,
-	   columns => [
-		       {
-			   table  => $u,
-			   column => $u
-			   }
-		       ],
-	    } ;
    }
 
     my %pa;
@@ -172,7 +124,7 @@ values (       ?,   ? ,   ?)';
        $sth_ft->execute($label, $column->{table}, $column->{column});
    }	
 
-    open R, ">$sql.sql_cat" or die "can't open register:!";
+    open R, ">register.log" or die "can't open register:!";
 
     my $log = "[$label] inserted as\n[$sql]\n";
 
@@ -183,24 +135,6 @@ values (       ?,   ? ,   ?)';
    
 }
 
-sub spider {
-
-    unless (cache_enabled) {
-	warn "Cache is not enabled. Cannot spider sql catalog.";
-    }
-
-    my $dbh = db_handle;
-
-    my $lookup = 'SELECT label,query FROM sql_catalog';
-    my $aref   = $dbh->selectall_hashref($lookup);
-
-    map {
-	cache($_->{label}, $_->{query})
-    } @$aref;
-
-}
-
-
 sub lookup {
 
     my ($class,$label) = @_;
@@ -209,14 +143,9 @@ sub lookup {
 
     warn "looking for label [$label]";
 
-    if (cache_enabled) {
-	my $label = cache($label);
-	return $label if $label;
-    }
-
     my $dbh = db_handle;
 
-    my $lookup = 'SELECT query FROM sql_catalog WHERE label = ?';
+    my $lookup = 'select query from sql_catalog where label = ?';
     my $sth = $dbh->prepare($lookup);
 
     $sth->execute($label);
@@ -226,19 +155,18 @@ sub lookup {
 
     my $row = $sth->fetchrow_hashref;
 
-    cache($label, $row->{query});
-
     $row->{query};
 
 }
 
 sub test {
+    warn "NO PLACEHOLDER VALUES SUPPLIED" unless @_;
     my ($class,$file,@bind_args) = @_;
-    warn "NO PLACEHOLDER VALUES SUPPLIED" unless @bind_args;
     my $sql = load_sql_from $file;
 
     my $parse = parse_sql $sql;
 
+
     my $dbh = db_handle;
     my $sth = $dbh->prepare($sql);
     
@@ -248,6 +176,7 @@ sub test {
 
     return unless ($parse->{command} =~ /select/i);
 
+
     open T, '>testexec.out' or die 'cannot create output file';
     print T "Query
 $sql
@@ -271,13 +200,13 @@ $sql
 
 }
 
-"True Value (Hardware)";
+1;
 __END__
-
+# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
-SQL::Catalog - query queries, label queries, db independant SQL, separate Perl and SQL
+SQL::Catalog - label queries, db independant SQL, separate Perl and SQL
 
 =head1 SYNOPSIS
 
@@ -286,26 +215,19 @@ SQL::Catalog - query queries, label queries, db independant SQL, separate Perl a
  shell% cat concrete.sql 
  select city, date from weather where temp_lo < 20 and temp_hi > 40 LIMIT 10
  shell% sql_test concrete.sql 
- # see results of prepare, execute on this
- shell% cat testexec.out 
+ shell% cat testexec.out # see results of prepare, execute on this
 
  shell% cat abstract.sql
  select city, date from weather where temp_lo < ? and temp_hi > ?
- # send in placeholder value
- shell% sql_test abstract.sql 55 
- # let's see results... looks good
- shell% cat testexec.out 
+ shell% sql_test abstract.sql 55 # send in placeholder value
+ shell% cat testexec.out # to see results... looks good
 
  shell% sql_register abstract.sql basic_weather "basic weather query"
- [basic_weather] inserted as 
+ [hi_and_low] inserted as 
  [select city from weather where temp_lo < ? and temp_hi > ?]
 
  ... then in a Perl program (e.g. test.pl in this distribution)
- 
- # Cache all queries to a Cache::Cache instead of runtime db-lookup
- % shell perl -MSQL::Catalog -e 'SQL::Catalog->spider'
-
- my $dbh = get_the_handle_as_you_please;
+ my $dbh = SQL::Catalog->db_handle; # optional - get the handle as you please
  my $sql = SQL::Catalog->lookup('hi_and_low');
  my $sth = $dbh->prepare($sql);
  $sth->execute(55);
@@ -324,13 +246,9 @@ necessary. And before this module, time-consuming:
 
 You may at some time to be forced to deploy an application which has to
 work on more than one database. Prior to SQL::Catalog, there were two
-choices - DBIx::AnyDBD and DBIx::Recordset. SQL::Catalog will work well
-alongside the latter.
-
-Note though that because some databases can do in one query what takes
-4 in another (ie, Oracle has C<SELECT * FROM CREATE TABLE ...>),
-you may have to create subclasses of your database layer classes to actually
-handle each needed function. This is what DBIx::AnyDBD handles for you.
+choices - DBIx::AnyDBD and DBIx::Recordset. With SQL::Catalog, you
+simply store the SQL for a particular label in each database and you
+are done.
 
 =item * labelled queries
 
@@ -365,16 +283,6 @@ that is afforded to HTML designers be afforded to SQL programmers.
 This makes it easy for someone to see how 
 you did something so they can imitate.
 
-=item * memory preservation
-
-You may be sitting there thinking "this is no better than a Perl
-hashref". And if you are, then I congratulate you on making it to the
-6th bulleted item instead of impatiently finding something else to do.
-Anyway, the problem with using a Perl hashref is that it will consume 
-memory and in a large system memory is precious.
-
-Furthermore, you don't get the querying capabilities with a Perl hashref.
-
 =back
 
 SQL::Catalog addresses all of these issues.
@@ -434,18 +342,17 @@ See the README in the home directory of the distribution.
 
 =head1 What SQL::Catalog does
 
-It stores each query in a database table with the label as key and
-the SQL query as the one value for that key. Then there is a foreign
-table with a number of useful query attributes such as type of query, 
-tables and columns used and number of placeholders.
+It stores each query in a database table. I could have gone for
+something more normalized and exquisite in database design but wanted to 
+maintain 
+database independence without requiring extra tools for schema
+creation and database use. 
 
-Right now we have schema creation and SQL code which works for 
-MySQL (thanks to Jason W. May), Informix (thanks to Jonathan Leffler) 
-and Postgresql (thanks to me, although I did use Marcel Grunaer's
-DBIx::Renderer to make it) and welcome more.
+Right now we have schema creation and SQL code which works for Informix and
+Postgresql and welcome more.
 
 The queries are stored in these tables
-(this file is C<db-creation/postgresql.sql>):
+(this file is C<db-creation/postgresql.renderer>):
 
  CREATE TABLE sql_catalog (
         label varchar(80) ,
@@ -483,10 +390,6 @@ And here is the result of ONE sql_register:
  (1 row)
 
 
-Queries are only *stored* in the database, by calling
-C<SQL::Catalog->spider>, you can move them into main memory or a file cache
-or whatever other kind of cache that C<Cache::Cache> supports.
-
 =head1 NOTES
 
 =over 4
@@ -513,8 +416,6 @@ data database connects based on a different DSN.
 T. M. Brannon, <tbone@cpan.org>
 
 Substantial contribution (and ass-kicking) by Jonathan Leffler.
-MySQL table creation code contribution by Jason W. May.
-
 
 =head1 SEE ALSO
 
@@ -523,20 +424,12 @@ SQL::Catalog does.
 
 =over 4
 
-=item * L<Ima::DBI|Ima::DBI> provides an object-oriented interface to
-connection and sql management.
-
-=item * L<DBIx::Librarian|DBIx::Librarian> provides labelled access to 
-queries and shortens the prepare-execute ritual a bit.
-
-=item * L<Class::Phrasebook::SQL|Class::Phrasebook::SQL>
-stores a "phrasebook" of SQL in XML
+=item * Class::Phrasebook::SQL stores a "phrasebook" of SQL in XML
 files. Allows for retrieval of queries via a convenient API. The
 querying of queries that SQL::Catalog supports can be done using an
 XML processor along with SQL::Statement.
 
-=item * L<DBIx::SearchProfiles|DBIx::SearchProfiles>. 
-Does query labeling and also has some
+=item * L<DBIx::SearchProfiles>. Does query labeling and also has some
 convenience functions for query retrieval. It does not store the SQL
 in a database or make it searchable by table, column, or number of
 placeholders. Your standard Perl data munging techniques would be the way to
